@@ -78,10 +78,9 @@ class simplifyWKT():
 
         try:
             # wkt.loads doesn't like 3D/4D tags, BUT it loads the coords just fine:
+            # (Needed until https://github.com/geomet/geomet/issues/58 is fixed)
             wkt_str = wkt_str.upper()
-            wkt_str = wkt_str.replace(" Z ", " ")
-            wkt_str = wkt_str.replace(" M ", " ")
-            wkt_str = wkt_str.replace(" ZM ", " ")
+            wkt_str = wkt_str.replace(" Z ", " ").replace(" M ", " ").replace(" ZM ", " ")
             wkt_json = wkt.loads(wkt_str)
         except AttributeError as e:
             self.errors = { 'errors': [{'type': 'ATTRIBUTE', 'report': 'Could not parse WKT: {0}.'.format(str(e))}] }
